package com.lddubeau.oowebdict.comp;

import java.net.MalformedURLException;

import com.lddubeau.ddb.BasicLexicon;
import com.lddubeau.ddb.CancelledByUser;
import com.lddubeau.oowebdict.comp.IndexImpl.ProgressGlue;
import com.sun.star.lang.XSingleComponentFactory;
import com.sun.star.lib.uno.helper.Factory;
import com.sun.star.lib.uno.helper.WeakBase;
import com.sun.star.registry.XRegistryKey;
import com.sun.star.uno.Exception;
import com.sun.star.uno.XComponentContext;

public final class BasicLexiconImpl extends WeakBase
		implements
			com.sun.star.lang.XInitialization,
			com.lddubeau.oowebdict.XBasicLexicon,
			com.sun.star.lang.XServiceInfo
{
	private final XComponentContext m_xContext;

	private static final String m_implementationName = BasicLexiconImpl.class
			.getName();

	protected static final String __serviceName = "com.lddubeau.oowebdict.BasicLexicon";

	private BasicLexicon lexicon = null;

	public BasicLexiconImpl(XComponentContext context)
	{
		m_xContext = context;
	};

	public static XSingleComponentFactory __getComponentFactory(
			String sImplementationName)
	{
		XSingleComponentFactory xFactory = null;

		if (sImplementationName.equals(m_implementationName))
			xFactory = Factory.createComponentFactory(BasicLexiconImpl.class,
					new String[]{__serviceName});
		return xFactory;
	}

	public static boolean __writeRegistryServiceInfo(XRegistryKey xRegistryKey)
	{
		return Factory.writeRegistryServiceInfo(m_implementationName,
				new String[]{__serviceName}, xRegistryKey);
	}

	// com.sun.star.lang.XInitialization:
	public void initialize(Object [] aArguments)
			throws com.sun.star.uno.Exception
	{
		try
		{
			String url = (String) aArguments[0];
			this.lexicon = new BasicLexicon(url, new ProgressGlue(url));
		}
		catch (MalformedURLException ex)
		{
			throw new Exception("bad URL " + (String) aArguments[0] + " "
					+ ex.toString());
		}
	}

	// com.lddubeau.oowebdict.XBasicLexicon:
	public boolean exists(String term)
			throws com.lddubeau.oowebdict.CancelledByUser
	{
		try
		{
			return this.lexicon.exists(term);
		}
		catch (CancelledByUser e)
		{
			throw new com.lddubeau.oowebdict.CancelledByUser();
		}
	}

	public int getLongestTermLength()
			throws com.lddubeau.oowebdict.CancelledByUser
	{
		try
		{
			return this.lexicon.getLongestTermLength();
		}
		catch (CancelledByUser e)
		{
			throw new com.lddubeau.oowebdict.CancelledByUser();
		}
	}

	public String getTermData(String term)
			throws com.lddubeau.oowebdict.CancelledByUser
	{
		try
		{
			String ret = this.lexicon.getTermData(term);
			// By IDL requirements, we can't return null. 
			return (ret == null)?"":ret;
		}
		catch (CancelledByUser e)
		{
			throw new com.lddubeau.oowebdict.CancelledByUser();
		}
	}

	// com.sun.star.lang.XServiceInfo:
	public String getImplementationName()
	{
		return m_implementationName;
	}

	public boolean supportsService(String sService)
	{
		return sService.equals(__serviceName);
	}

	public String [] getSupportedServiceNames()
	{
		return new String[] {__serviceName};
	}

}
