package com.lddubeau.oowebdict.comp;

import java.net.MalformedURLException;

import com.lddubeau.ddb.CancelledByUser;
import com.lddubeau.ddb.Index;
import com.lddubeau.ddb.ProgressMonitor;
import com.lddubeau.oowebdict.LastBuild;
import com.sun.star.lang.XSingleComponentFactory;
import com.sun.star.lib.uno.helper.Factory;
import com.sun.star.lib.uno.helper.WeakBase;
import com.sun.star.registry.XRegistryKey;
import com.sun.star.uno.Exception;
import com.sun.star.uno.XComponentContext;

public final class IndexImpl extends WeakBase
		implements
			com.sun.star.lang.XServiceInfo,
			com.lddubeau.oowebdict.XIndex,
			com.sun.star.lang.XInitialization
{
	private final XComponentContext m_xContext;

	private static final String m_implementationName = IndexImpl.class
			.getName();

	protected static final String __serviceName = "com.lddubeau.oowebdict.Index";

	private Index index = null;

	public IndexImpl(XComponentContext context)
	{
		m_xContext = context;
	};

	public static XSingleComponentFactory __getComponentFactory(
			String sImplementationName)
	{
		XSingleComponentFactory xFactory = null;

		if (sImplementationName.equals(m_implementationName))
			xFactory = Factory.createComponentFactory(IndexImpl.class,
					new String[]{__serviceName});
		return xFactory;
	}

	public static boolean __writeRegistryServiceInfo(XRegistryKey xRegistryKey)
	{
		return Factory.writeRegistryServiceInfo(m_implementationName,
				new String[]{__serviceName}, xRegistryKey);
	}

	// com.sun.star.lang.XServiceInfo:
	public String getImplementationName()
	{
		return m_implementationName;
	}

	public boolean supportsService(String sService)
	{
		return sService.equals(__serviceName);
	}

	public String [] getSupportedServiceNames()
	{
		return new String[]{__serviceName};
	}

	// com.lddubeau.oowebdict.XIndex:
	public boolean exists(String term)
			throws com.lddubeau.oowebdict.CancelledByUser
	{
		try
		{
			return this.index.exists(term);
		}
		catch (CancelledByUser e)
		{
			throw new com.lddubeau.oowebdict.CancelledByUser();
		}
	}

	public int getLongestTermLength()
			throws com.lddubeau.oowebdict.CancelledByUser

	{
		try
		{
			return this.index.getLongestTermLength();
		}
		catch (CancelledByUser e)
		{
			throw new com.lddubeau.oowebdict.CancelledByUser();
		}
	}

	public String getBuildTime()
	{
		return LastBuild.getTime();
	}

	public String getVersion()
	{
		return LastBuild.getVersion();
	}

	public int getMajor()
	{
		return LastBuild.getMajor();
	}

	public int getMinor()
	{
		return LastBuild.getMinor();
	}

	public String getVersions()
	{
		return Index.getVersions() + "\nOOWebDict version: " + getVersion();
	}

	// com.sun.star.lang.XInitialization:
	public void initialize(Object [] aArguments)
			throws com.sun.star.uno.Exception
	{
		try
		{
			String url = (String) aArguments[0];
			this.index = new Index(url, new ProgressGlue(url));
		}
		catch (MalformedURLException ex)
		{
			throw new Exception("bad URL " + (String) aArguments[0] + " "
					+ ex.toString());
		}
	}

	static final class ProgressGlue implements ProgressMonitor
	{
		private final javax.swing.ProgressMonitor monitor;

		public ProgressGlue(String url)
		{
			this.monitor = new javax.swing.ProgressMonitor(null,
					"Loading from: " + url, "", 0, 0);
		}

		public void close()
		{
			this.monitor.close();
		}

		public boolean isCancelled()
		{
			return this.monitor.isCanceled();
		}

		public void setMaximum(int m)
		{
			this.monitor.setMaximum(m);
		}

		public void setMinimum(int m)
		{
			this.monitor.setMinimum(m);
		}

		public void setProgress(int m)
		{
			this.monitor.setProgress(m);
		}
	}

}
