package com.lddubeau.oowebdict.comp;

import com.sun.star.comp.loader.FactoryHelper;
import com.sun.star.lang.XMultiServiceFactory;
import com.sun.star.lang.XSingleServiceFactory;
import com.sun.star.registry.XRegistryKey;

public final class OoRegistration
{
	private static final ClassInfo [] info;
	
	static
	{
		final Class<?> [] classes = new Class<?> [] {IndexImpl.class, BasicLexiconImpl.class};
		info = new ClassInfo[classes.length];
		int info_ix = 0;
		for(Class<?> c: classes)
		{
			String serviceName = null;
			try
			{
				serviceName = (String) c.getDeclaredField("__serviceName").get(c);
			}
			catch(NoSuchFieldException e)
			{
				throw new Error("field __serviceName must be defined on class " + c.getName(), e);
			}
			catch(SecurityException e)
			{
				throw new Error("can't get field __serviceName on class " + c.getName(), e);
			}
			catch(IllegalAccessException e)
			{
				throw new Error("can't get field __serviceName on class " + c.getName(), e);
			}
			info[info_ix] = new ClassInfo();
			info[info_ix].c = c;
			info[info_ix].name = c.getName();
			info[info_ix].serviceName = serviceName;
			info_ix++;
		}
	}
	
	public static XSingleServiceFactory __getServiceFactory(String implName,
			XMultiServiceFactory multiFactory, XRegistryKey regKey)
	{
		XSingleServiceFactory xSingleServiceFactory = null;
		for(ClassInfo i: info)
		{
			if (implName.equals(i.name))
			{
				xSingleServiceFactory = FactoryHelper.getServiceFactory(
						i.c, i.serviceName, multiFactory, regKey);
				return xSingleServiceFactory;
			}
		}
		return xSingleServiceFactory;
	}

	public static boolean __writeRegistryServiceInfo(XRegistryKey regKey)
	{
		boolean b = true;
		for (ClassInfo i : info)
		{
			b = b && FactoryHelper.writeRegistryServiceInfo(i.name, i.serviceName, regKey); 
		}
		return b;
	}
	
	private final static class ClassInfo
	{
		public Class<?> c;
		public String name;
		public String serviceName;
	}
}
